# snipsearch

Python package to search multiple strings within Python snippets.

## Install

pip install snipsearch

## Usage



## Read The Docs

Download "docs" folder or check preview below.

https://htmlpreview.github.io/?https://github.com/jkrist2696/snipsearch/blob/main/docs/index.html


## Contributing

Message me on Github.

## License

[GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)

## Copyright:

(c) 2023, Jason Krist